==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/NextWeekExpressionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { OffsettableWeekExpressionDescriptionMetadata } from "./OffsettableWeekExpressionDescriptionMetadata";
import { NextWeekExpressionDescription } from "./NextWeekExpressionDescription";
/**
 * @hidden
 */
var NextWeekExpressionDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(NextWeekExpressionDescriptionMetadata, _super);
    function NextWeekExpressionDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    NextWeekExpressionDescriptionMetadata.b = function (a) {
        if (NextWeekExpressionDescriptionMetadata.a == null) {
            NextWeekExpressionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            NextWeekExpressionDescriptionMetadata.c(NextWeekExpressionDescriptionMetadata.a);
        }
        if (a.j(NextWeekExpressionDescriptionMetadata.a)) {
            return;
        }
        a.y(NextWeekExpressionDescriptionMetadata.a);
    };
    NextWeekExpressionDescriptionMetadata.c = function (a) {
        OffsettableWeekExpressionDescriptionMetadata.c(a);
    };
    NextWeekExpressionDescriptionMetadata.d = function (a) {
        NextWeekExpressionDescriptionMetadata.b(a);
        a.aa("NextWeekExpression", function () { return new NextWeekExpressionDescription(); });
        a.z("NextWeekExpression", NextWeekExpressionDescriptionMetadata.a);
    };
    NextWeekExpressionDescriptionMetadata.$t = markType(NextWeekExpressionDescriptionMetadata, 'NextWeekExpressionDescriptionMetadata');
    NextWeekExpressionDescriptionMetadata.a = null;
    return NextWeekExpressionDescriptionMetadata;
}(Base));
export { NextWeekExpressionDescriptionMetadata };

==> igniteui-react-core-18.1.3.tgz: package/esm5/lib/NextWeekExpressionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { OffsettableWeekExpressionDescriptionMetadata } from "./OffsettableWeekExpressionDescriptionMetadata";
import { NextWeekExpressionDescription } from "./NextWeekExpressionDescription";
/**
 * @hidden
 */
var NextWeekExpressionDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(NextWeekExpressionDescriptionMetadata, _super);
    function NextWeekExpressionDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    NextWeekExpressionDescriptionMetadata.b = function (a) {
        if (NextWeekExpressionDescriptionMetadata.a == null) {
            NextWeekExpressionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            NextWeekExpressionDescriptionMetadata.c(NextWeekExpressionDescriptionMetadata.a);
        }
        if (a.k(NextWeekExpressionDescriptionMetadata.a)) {
            return;
        }
        a.aa(NextWeekExpressionDescriptionMetadata.a);
    };
    NextWeekExpressionDescriptionMetadata.c = function (a) {
        OffsettableWeekExpressionDescriptionMetadata.c(a);
    };
    NextWeekExpressionDescriptionMetadata.d = function (a) {
        NextWeekExpressionDescriptionMetadata.b(a);
        a.ac("NextWeekExpression", function () { return new NextWeekExpressionDescription(); });
        a.ab("NextWeekExpression", NextWeekExpressionDescriptionMetadata.a);
    };
    NextWeekExpressionDescriptionMetadata.$t = markType(NextWeekExpressionDescriptionMetadata, 'NextWeekExpressionDescriptionMetadata');
    NextWeekExpressionDescriptionMetadata.a = null;
    return NextWeekExpressionDescriptionMetadata;
}(Base));
export { NextWeekExpressionDescriptionMetadata };
